@@ -1856,41 +1856,3 @@ while (*s != 0 && !isdigit(*s))
     ++s;
 return s;
 }
-
-#ifndef WIN32
-time_t mktimeFromUtc (struct tm *t)
-/* Return time_t for tm in UTC (GMT)
- * Useful for stuff like converting to time_t the
- * last-modified HTTP response header
- * which is always GMT. Returns -1 on failure of mktime */
-{
-    time_t time;
-    char *tz;
-    char save_tz[100];
-    tz=getenv("TZ");
-    if (tz)
-        safecpy(save_tz, sizeof(save_tz), tz);
-    setenv("TZ", "GMT0", 1);
-    tzset();
-    t->tm_isdst = 0;
-    time=mktime(t);
-    if (tz)
-        setenv("TZ", save_tz, 1);
-    else
-        unsetenv("TZ");
-    tzset();
-    return (time);
-}
-
-
-time_t dateToSeconds(const char *date,const char*format)
-// Convert a string date to time_t
-{
-struct tm storage={0,0,0,0,0,0,0,0,0};
-if (strptime(date,format,&storage)==NULL)
-    return 0;
-else
-    return mktime(&storage);
-}
-
-#endif
